# LLM-Inflation

Code for my Machine Learning for Trading and Portfolio Management course project at ENSAE

## Installation

The package was published to PyPi, and can be installed using

```bash
pip install llm-inflation
```

## Usage

Please refer to the Colab notebook, and the code's docstrings.